<?php

/**
 * @file
 * Contains \Drupal\s3_db_backup\Adapter\S3DatabaseBackupLocalAdapter
 */

namespace Drupal\s3_db_backup\Adapter;

use Drupal\s3_db_backup\S3DatabaseBackup;
use Drupal\s3_db_backup\S3DatabaseBackupClientInterface;
use Drupal\file\Entity\File;
use Drupal\file\FileInterface;

/**
 * Class S3DatabaseBackupLocalAdapter.
 */
class S3DatabaseLocalBackupAdapter implements S3DatabaseBackupAdapterInterface {

  /**
   * @var \Drupal\s3_db_backup\S3DatabaseBackupClientInterface
   */
  protected $backupDatabaseClient;

  /**
   * @var \Drupal\s3_db_backup\S3DatabaseBackup
   */
  protected $backupDatabase;

  /**
   * @param \Drupal\s3_db_backup\S3DatabaseBackupClientInterface $backupDatabaseClient
   * @param \Drupal\s3_db_backup\S3DatabaseBackup $backupDatabase
   */
  public function __construct(S3DatabaseBackupClientInterface $backupDatabaseClient, S3DatabaseBackup $backupDatabase) {
    $this->backupDatabaseClient = $backupDatabaseClient;
    $this->backupDatabase = $backupDatabase;
  }

  /**
   * Export routine.
   *
   * @inherit
   * @throws \Drupal\Core\Entity\EntityStorageException
   * @throws \Exception
   */
  public function export(): int {
    $handler = $this->backupDatabaseClient->getFileHandler();
    $handler->setupFile($this->backupDatabaseClient->getSettings());

    $file = $handler->getFile();
    $user = \Drupal::currentUser();

    // Create a file entity.
    $entity = File::create([
      'uri' => $file->getFileUri(),
      'uid' => $user->id(),
      'status' => FileInterface::STATUS_PERMANENT,
    ]);
    $entity->save();

    // Insert history entry.
    if ($entity->id()) {
      $this->backupDatabase->addHistoryEntry([
        'fid' => $entity->id(),
        'name' => $file->getFileName(),
        'uri' => $file->getFileUri(),
      ]);
      $export = $this->backupDatabaseClient->dump();
      $export->start($file->getFileUri());
    }
    else {
      \Drupal::logger('s3_db_backup')->error('File entity could not be created.');
    }

    return (int) $entity->id();
  }

}
