<?php

/**
 * @file
 * Contains \Drupal\s3_db_backup\Adapter\S3DatabaseBackupRemoteAdapter
 */

namespace Drupal\s3_db_backup\Adapter;

use Drupal\s3_db_backup\S3DatabaseBackup;
use Drupal\s3_db_backup\S3DatabaseBackupClientInterface;
use Symfony\Component\HttpFoundation\BinaryFileResponse;
use Symfony\Component\HttpFoundation\ResponseHeaderBag;
use Symfony\Component\HttpFoundation\Request;

/**
 * Class S3DatabaseBackupRemoteAdapter.
 */
class S3DatabaseRemoteBackupAdapter implements S3DatabaseBackupAdapterInterface {

  /**
   * @var \Drupal\s3_db_backup\S3DatabaseBackupClientInterface
   */
  protected $backupDatabaseClient;

  /**
   * @var \Drupal\s3_db_backup\S3DatabaseBackup
   */
  protected $backupDatabase;

  /**
   * @param \Drupal\s3_db_backup\S3DatabaseBackupClientInterface $backupDatabaseClient
   * @param \Drupal\s3_db_backup\S3DatabaseBackup $backupDatabase
   */
  public function __construct(S3DatabaseBackupClientInterface $backupDatabaseClient, S3DatabaseBackup $backupDatabase) {
    $this->backupDatabaseClient = $backupDatabaseClient;
    $this->backupDatabase = $backupDatabase;
  }

  /**
   * Export routine.
   *
   * @inherit
   */
  public function export(): int {
    $handler = $this->backupDatabaseClient->getFileHandler();
    $handler->setupFile($this->backupDatabaseClient->getSettings());

    $file = $handler->getFile();

    $export = $this->backupDatabaseClient->dump();
    $export->start($file->getFileUri());

    $this->download($file->getFileUri(), [
      'name' => $file->getFileName(),
      'type' => $file->getFileType(),
    ]);

    return TRUE;
  }

  /**
   * Expose the export for download.
   *
   * @param string $path
   * @param array $config
   */
  private function download(string $path, array $config) {
    $response = new BinaryFileResponse($path);
    $response->trustXSendfileTypeHeader();
    $response->headers->set('Content-Type', $config['type']);
    $response->setContentDisposition(
      ResponseHeaderBag::DISPOSITION_ATTACHMENT,
      $config['name']
    );
    $response->prepare(Request::createFromGlobals());
    $response->send();
  }

}
